<?php
/**
 * @file
 *
 * Contains the exportable UI for the Socrata module's sources
 */

/**
 * Define this Export UI plugin.
 */
$plugin = array(
  'schema' => 'calameo_accounts',  // As defined in hook_schema().
  'access' => 'administer calameo accounts',  // Define a permission users must have to access these pages.

  // Define the menu item.
  'menu' => array(
    'menu item' => 'calameo',
    'menu title' => 'Calameo',
    'menu description' => 'Administer Calameo accounts',
  ),

  // Define user interface texts.
  'title singular' => t('account'),
  'title plural' => t('accounts'),
  'title singular proper' => t('Calameo account'),
  'title plural proper' => t('Calameo accounts'),

  // Define the names of the functions that provide the add/edit forms.
  'form' => array(
    'settings' => '_calameo_ctools_export_ui_form',
    'validate' => '_calameo_ctools_export_ui_form_validate',
    'submit' => '_calameo_ctools_export_ui_form_submit',
  ),
  'handler' => array(
    'class' => 'calameo_export_ui',
    'parent' => 'ctools_export_ui',
  ),
);

/**
 * Define the source add/edit form
 */
function _calameo_ctools_export_ui_form(&$form, &$form_state) {
  $source = $form_state['item'];

  $form['human_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Human-readable name'),
    '#description' => t('The human readable name for this account'),
    '#default_value' => $source->human_name,
    '#required' => TRUE,
  );

  $form['endpoint'] = array(
    '#type' => 'textfield',
    '#title' => t('Endpoint URL'),
    '#description' => t('The endpoint URL for the API'),
    '#default_value' => !empty($source->endpoint) ? $source->endpoint : 'http://api.calameo.com/1.0',
    '#required' => TRUE,
  );

  $form['api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('API key'),
    '#description' => t('The API key provided by Calameo.'),
    '#default_value' => $source->api_key,
    '#required' => TRUE,
  );

  $form['api_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('API secret'),
    '#description' => t('The API secret provided by Calameo'),
    '#default_value' => $source->api_secret,
    '#required' => TRUE,
  );
}

/**
 * Handle validation of the source add/edit form
 */
function _calameo_ctools_export_ui_form_validate(&$form, &$form_state) {
  $values = $form_state['values'];

  // Validate endpoint URL for dataset
  if (!valid_url($values['endpoint'], TRUE)) {
    form_set_error('endpoint', t('The URL is not properly formed'));
  }
}

/**
 * Handle submission of the source add/edit form
 */
function _calameo_ctools_export_ui_form_submit(&$form, &$form_state) {
}

/**
 * CTools export UI extending class. Slightly customized for Calameo.
 */
class calameo_export_ui extends ctools_export_ui {
  /**
   * Provide a list of sort options.
   *
   * Override this if you wish to provide more or change how these work.
   * The actual handling of the sorting will happen in build_row().
   */
  function list_sort_options() {
    $options = array(
      'disabled' => t('Enabled, name'),
      'human_name' => t('Name'),
      'storage' => t('Storage'),
    );

    return $options;
  }

  /**
   * Build a row based on the item.
   *
   * By default all of the rows are placed into a table by the render
   * method, so this is building up a row suitable for theme('table').
   * This doesn't have to be true if you override both.
   */
  function list_build_row($item, &$form_state, $operations) {
    // Set up sorting
    $name = $item->{$this->plugin['export']['key']};
    $schema = ctools_export_get_schema($this->plugin['schema']);

    // Note: $item->{$schema['export']['export type string']} should have already been set up by export.inc so
    // we can use it safely.
    switch ($form_state['values']['order']) {
      case 'disabled':
        $this->sorts[$name] = empty($item->disabled) . $item->human_name;
        break;
      case 'human_name':
        $this->sorts[$name] = $item->human_name;
        break;
      case 'storage':
        $this->sorts[$name] = $item->{$schema['export']['export type string']} . $name;
        break;
    }

    $this->rows[$name]['data'] = array();
    $this->rows[$name]['class'] = !empty($item->disabled) ? array('ctools-export-ui-disabled') : array('ctools-export-ui-enabled');

    $this->rows[$name]['data'][] = array('data' => check_plain($item->human_name), 'class' => array('ctools-export-ui-name'));
    $this->rows[$name]['data'][] = array('data' => check_plain($name), 'class' => array('ctools-export-ui-name'));
    $this->rows[$name]['data'][] = array('data' => check_plain($item->{$schema['export']['export type string']}), 'class' => array('ctools-export-ui-storage'));

    $ops = theme('links__ctools_dropbutton', array('links' => $operations, 'attributes' => array('class' => array('links', 'inline'))));

    $this->rows[$name]['data'][] = array('data' => $ops, 'class' => array('ctools-export-ui-operations'));

    // Add an automatic mouseover of the description if one exists.
    if (!empty($this->plugin['export']['admin_description'])) {
      $this->rows[$name]['title'] = $item->{$this->plugin['export']['admin_description']};
    }
  }

  /**
   * Provide the table header.
   *
   * If you've added columns via list_build_row() but are still using a
   * table, override this method to set up the table header.
   */
  function list_table_header() {
    $header = array();
    if (!empty($this->plugin['export']['admin_title'])) {
      $header[] = array('data' => t('Title'), 'class' => array('ctools-export-ui-title'));
    }

    $header[] = array('data' => t('Name'), 'class' => array('ctools-export-ui-human-name'));
    $header[] = array('data' => t('Machine Name'), 'class' => array('ctools-export-ui-name'));
    $header[] = array('data' => t('Storage'), 'class' => array('ctools-export-ui-storage'));
    $header[] = array('data' => t('Operations'), 'class' => array('ctools-export-ui-operations'));

    return $header;
  }
}
